@@ -11,13 +11,16 @@ module OmniAuth
           token_url: '/oauth/token'
       }
 
+      option :redirect_url
+
       uid { raw_info['id'].to_s }
 
       info do
         {
             name:     raw_info['name'],
             username: raw_info['username'],
-            email:    raw_info['email']
+            email:    raw_info['email'],
+            image:    raw_info['avatar_url']
         }
       end
 
@@ -28,6 +31,12 @@ module OmniAuth
       def raw_info
         @raw_info ||= access_token.get('/api/v3/user').parsed
       end
+
+      private
+
+      def callback_url
+        options.redirect_url || (full_host + script_name + callback_path)
+      end
     end
   end
 end
